# mrwm

## Note: remember to uninstall module after you are done with practical

### For Code
```python
import mrwm
mrwm.main()
```

```
output:

1_EComAmazon
2_PageRank
3_SpamClassifier
4_TextMining
5_AprioriAlgorithmCase
6_BasicCrawler
7_FocusedCrawler
8_SentimentAnalysis

1


<code as an output>
```

### For Description
```python
import mrwm
mrwm.desc()
```

```
output:

1_EComAmazon
2_PageRank
3_SpamClassifier
4_TextMining
5_AprioriAlgorithmCase
6_BasicCrawler
7_FocusedCrawler
8_SentimentAnalysis

1


<description as an output>
```